.. image:: https://badge.fury.io/py/tox.svg
  :target: https://badge.fury.io/py/tox
  :alt: Latest version on PyPi
.. image:: https://img.shields.io/pypi/pyversions/tox.svg
  :target: https://pypi.org/project/tox/
  :alt: Supported Python versions
.. image:: https://dev.azure.com/toxdev/tox/_apis/build/status/tox%20ci?branchName=master
  :target: https://dev.azure.com/toxdev/tox/_build/latest?definitionId=9&branchName=master
  :alt: Azure Pipelines build status
.. image:: https://api.codeclimate.com/v1/badges/425c19ab2169a35e1c16/test_coverage
   :target: https://codeclimate.com/github/tox-dev/tox/code?sort=test_coverage
   :alt: Test Coverage
.. image:: https://readthedocs.org/projects/tox/badge/?version=latest&style=flat-square
  :target: https://tox.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation status
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
  :target: https://github.com/ambv/black
  :alt: Code style: black

tox automation project
======================

**vision: standardize testing in Python**

tox aims to automate and standardize testing in Python. It is part of a larger vision of easing the packaging, testing and release process of Python software.

What is tox?
============

tox is a generic virtualenv management and test command line tool you can use for:

* checking your package installs correctly with different Python versions and
  interpreters

* running your tests in each of the environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration servers, greatly
  reducing boilerplate and merging CI and shell-based testing.

For more information and the repository please see:

- home and docs: https://tox.readthedocs.org

- repository: https://github.com/tox-dev/tox
